Name: dnsmasq
Version: 2.22

# Handle initscript style change between ALTLinux Master 2.2
# (classic RedHat initscripts with daemon and killproc functions)
# and ALTLinux Master 2.4 (start_daemon and stop_daemon functions).
# Build for M22 works well under M24, but cannot be delivered
# to official ALTLinux Sisyphus repository.

%define dist_tag %nil

%if_with Master22
%define dist_tag master22
%endif

%if_with Master24
%define dist_tag master24
%endif

%if "%dist_tag" == ""
%if "%(test -e %_initdir/functions-compat && echo M24)" == ""
%define dist_tag master22
%else
%define dist_tag master24
%endif
%endif

%if "%dist_tag" == "master22"
%define release_tag .M22
%define m4_macro M22
%define service_pkg initscripts
%else
%define release_tag %nil
%define m4_macro M24
%define service_pkg service
%endif

Release: alt2%release_tag
Summary: A lightweight caching nameserver
Copyright: GPL
Group: System/Servers
URL: http://www.thekelleys.org.uk/dnsmasq
Source0: %url/%name-%version.tar.gz
Source1: %name.init.m4
Source2: %name.sysconfig
Patch0: %name.conf.patch
Patch1: %name-2.21-alt-includes.patch
Requires: %service_pkg
BuildPreReq: m4
# Conflicts: named, bind, dhcp, dhcpd

%define init_script rpm/%name-alt.%m4_macro
%define sysconfig_file %_sysconfdir/sysconfig/%name

Summary(ru_RU.KOI8-R):   DNS  DHCP   

%description
Dnsmasq is lightweight, easy to configure DNS forwarder and DHCP server. It 
is designed to provide DNS and, optionally, DHCP, to a small network. It can
serve the names of local machines which are not in the global DNS. The DHCP 
server integrates with the DNS server and allows machines with DHCP-allocated
addresses to appear in the DNS with names configured either in each host or 
in a central configuration file. Dnsmasq supports static and dynamic DHCP 
leases and BOOTP for network booting of diskless machines.

%description -l ru_RU.KOI8-R
Dnsmasq -  ,     DNS  DHCP,
     .

%prep
%setup -q
%patch0
#patch1

%build
%make_build

%install
echo Initialization script style: %dist_tag
m4 -D%m4_macro %SOURCE1 > %init_script
install -pD -m700 src/dnsmasq        %buildroot%_sbindir/%name
install -pD -m744 %init_script       %buildroot%_initdir/%name
install -pD -m600 %SOURCE2           %buildroot%sysconfig_file
install -pD -m600 %name.conf.example %buildroot%_sysconfdir/%name.conf
install -pD -m444 %name.8            %buildroot%_man8dir/%name.8

%pre
# Upgrade configuration from previous versions
if egrep -q '^[^#]*ALL *=' %sysconfig_file; then
    if ! egrep -q '^[^#]*ALL_DEV *=' %sysconfig_file; then
	echo 'NOTE: You should put ALL_DEV=<interface> to %sysconfig_file'
	echo '      for keeping DHCP broadcasts mode.'
    fi
fi

%post
%post_service %name

%preun
%preun_service %name
%__rm -f %_sysconfdir/*.dnsmasq 2>&1   # fixme! should be more elegant..

%files
%doc CHANGELOG COPYING FAQ doc.html setup.html UPGRADING_to_2.0
%config(noreplace) %_sysconfdir/%name.conf
%config(noreplace) %_sysconfdir/sysconfig/%name
%_initdir/%name
%_sbindir/%name
%_man8dir/%{name}*

%changelog
* Mon Jul 11 2005 Ilya Evseev <evseev@altlinux.ru> 2.22-alt2%release_tag
- bugfix #7223: use '/sbin/ip route' instead 'sbin/route' in service script
- service script bugfix: m4 previously intercepts 'shift' as keyword

* Sun Apr  3 2005 Ilya Evseev <evseev@altlinux.ru> 2.22-alt1%release_tag
- Updated to version 2.22, patch #1 is no more needed

* Fri Mar 25 2005 Ilya Evseev <evseev@altlinux.ru> 2.21-alt1%release_tag
- Updated to version 2.21
- Added includes patch (P1)

* Tue Jan 25 2005 Ilya Evseev <evseev@altlinux.ru> 2.20-alt1%release_tag
- 2.20
- URL is changed back from mantainer site to author site

* Sat Dec 18 2004 Ilya Evseev <evseev@altlinux.ru> 2.19-alt1%release_tag
- version 2.19
- IMPORTANT bugfixes in service script

* Thu Nov 25 2004 Ilya Evseev <evseev@altlinux.ru> 2.18-alt1%release_tag
- version 2.18

* Wed Oct 27 2004 Ilya Evseev <evseev@altlinux.ru> 2.16-alt1%release_tag
- version 2.16

* Wed Sep 22 2004 Ilya Evseev <evseev@altlinux.ru> 2.15-alt1%release_tag
- version 2.15

* Sun Sep 12 2004 Ilya Evseev <evseev@altlinux.ru> 2.14-alt1%release_tag
- version 2.14

* Tue Sep  7 2004 Ilya Evseev <evseev@altlinux.ru> 2.13-alt4%release_tag
- service script bugfixes:
   + domain name detection: added 'hostname --domain'
   + options are previously not passed to daemon
- sysconfig: added listening on 127.0.0.1 only for better security
- dnsmasq.conf: domain-needed and expand-hosts are enabled by default

* Sat Aug 28 2004 Ilya Evseev <evseev@altlinux.ru> 2.13-alt3%release_tag
- more once attempt to fit hasher restrictions:
   + detection rule is changed again
   + removed 'BuildPreReq: initscripts'

* Fri Aug 27 2004 Ilya Evseev <evseev@altlinux.ru> 2.13-alt2%release_tag
- added 'BuildPreReq: initscripts' for correct platform detection
  in build environment like hasher/sisyphus_check; changed detection rule.

* Sun Aug 22 2004 Ilya Evseev <evseev@altlinux.ru> 2.13-alt1%release_tag
- new release
- also update configuration file
- service script is generated separately
  for ALTLinux 2.2 (classic style) and 2.4beta (modern style)
- removed 'Requires: initscripts' for preventing problems with sisyphus_check

* Wed Aug  4 2004 Ilya Evseev <evseev@altlinux.ru> 2.10-alt2
- added 'Requires: initscripts' for preventing problems with automated building

* Tue Jul 29 2004 Ilya Evseev <evseev@altlinux.ru> 2.10-alt1
- initial build

## EOF ##
